==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkContourWidget.java <==
// java wrapper for vtkContourWidget object
//

package vtk;
import vtk.*;

public class vtkContourWidget extends vtkAbstractWidget
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetEnabled_2(int id0);
  public void SetEnabled(int id0)
    { SetEnabled_2(id0); }

  private native void SetRepresentation_3(vtkContourRepresentation id0);
  public void SetRepresentation(vtkContourRepresentation id0)
    { SetRepresentation_3(id0); }

  private native long GetContourRepresentation_4();
  public vtkContourRepresentation GetContourRepresentation() {
    long temp = GetContourRepresentation_4();

    if (temp == 0) return null;
    return (vtkContourRepresentation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void CreateDefaultRepresentation_5();
  public void CreateDefaultRepresentation()
    { CreateDefaultRepresentation_5(); }

  private native void CloseLoop_6();
  public void CloseLoop()
    { CloseLoop_6(); }

  private native void SetWidgetState_7(int id0);
  public void SetWidgetState(int id0)
    { SetWidgetState_7(id0); }

  private native int GetWidgetState_8();
  public int GetWidgetState()
    { return GetWidgetState_8(); }

  private native void SetAllowNodePicking_9(int id0);
  public void SetAllowNodePicking(int id0)
    { SetAllowNodePicking_9(id0); }

  private native int GetAllowNodePicking_10();
  public int GetAllowNodePicking()
    { return GetAllowNodePicking_10(); }

  private native void AllowNodePickingOn_11();
  public void AllowNodePickingOn()
    { AllowNodePickingOn_11(); }

  private native void AllowNodePickingOff_12();
  public void AllowNodePickingOff()
    { AllowNodePickingOff_12(); }

  private native void SetFollowCursor_13(int id0);
  public void SetFollowCursor(int id0)
    { SetFollowCursor_13(id0); }

  private native int GetFollowCursor_14();
  public int GetFollowCursor()
    { return GetFollowCursor_14(); }

  private native void FollowCursorOn_15();
  public void FollowCursorOn()
    { FollowCursorOn_15(); }

  private native void FollowCursorOff_16();
  public void FollowCursorOff()
    { FollowCursorOff_16(); }

  private native void SetContinuousDraw_17(int id0);
  public void SetContinuousDraw(int id0)
    { SetContinuousDraw_17(id0); }

  private native int GetContinuousDraw_18();
  public int GetContinuousDraw()
    { return GetContinuousDraw_18(); }

  private native void ContinuousDrawOn_19();
  public void ContinuousDrawOn()
    { ContinuousDrawOn_19(); }

  private native void ContinuousDrawOff_20();
  public void ContinuousDrawOff()
    { ContinuousDrawOff_20(); }

  private native void Initialize_21(vtkPolyData id0,int id1,vtkIdList id2);
  public void Initialize(vtkPolyData id0,int id1,vtkIdList id2)
    { Initialize_21(id0,id1,id2); }

  private native void Initialize_22();
  public void Initialize()
    { Initialize_22(); }

  public vtkContourWidget() { super(); }

  public vtkContourWidget(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-armv7h.pkg.tar.xz: vtk/vtkContourWidget.java <==
// java wrapper for vtkContourWidget object
//

package vtk;
import vtk.*;

public class vtkContourWidget extends vtkAbstractWidget
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetEnabled_2(int id0);
  public void SetEnabled(int id0)
    { SetEnabled_2(id0); }

  private native void SetRepresentation_3(vtkContourRepresentation id0);
  public void SetRepresentation(vtkContourRepresentation id0)
    { SetRepresentation_3(id0); }

  private native long GetContourRepresentation_4();
  public vtkContourRepresentation GetContourRepresentation() {
    long temp = GetContourRepresentation_4();

    if (temp == 0) return null;
    return (vtkContourRepresentation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void CreateDefaultRepresentation_5();
  public void CreateDefaultRepresentation()
    { CreateDefaultRepresentation_5(); }

  private native void CloseLoop_6();
  public void CloseLoop()
    { CloseLoop_6(); }

  private native void SetWidgetState_7(int id0);
  public void SetWidgetState(int id0)
    { SetWidgetState_7(id0); }

  private native int GetWidgetState_8();
  public int GetWidgetState()
    { return GetWidgetState_8(); }

  private native void SetAllowNodePicking_9(int id0);
  public void SetAllowNodePicking(int id0)
    { SetAllowNodePicking_9(id0); }

  private native int GetAllowNodePicking_10();
  public int GetAllowNodePicking()
    { return GetAllowNodePicking_10(); }

  private native void AllowNodePickingOn_11();
  public void AllowNodePickingOn()
    { AllowNodePickingOn_11(); }

  private native void AllowNodePickingOff_12();
  public void AllowNodePickingOff()
    { AllowNodePickingOff_12(); }

  private native void SetFollowCursor_13(int id0);
  public void SetFollowCursor(int id0)
    { SetFollowCursor_13(id0); }

  private native int GetFollowCursor_14();
  public int GetFollowCursor()
    { return GetFollowCursor_14(); }

  private native void FollowCursorOn_15();
  public void FollowCursorOn()
    { FollowCursorOn_15(); }

  private native void FollowCursorOff_16();
  public void FollowCursorOff()
    { FollowCursorOff_16(); }

  private native void SetContinuousDraw_17(int id0);
  public void SetContinuousDraw(int id0)
    { SetContinuousDraw_17(id0); }

  private native int GetContinuousDraw_18();
  public int GetContinuousDraw()
    { return GetContinuousDraw_18(); }

  private native void ContinuousDrawOn_19();
  public void ContinuousDrawOn()
    { ContinuousDrawOn_19(); }

  private native void ContinuousDrawOff_20();
  public void ContinuousDrawOff()
    { ContinuousDrawOff_20(); }

  private native void Initialize_21(vtkPolyData id0,int id1,vtkIdList id2);
  public void Initialize(vtkPolyData id0,int id1,vtkIdList id2)
    { Initialize_21(id0,id1,id2); }

  private native void Initialize_22();
  public void Initialize()
    { Initialize_22(); }

  public vtkContourWidget() { super(); }

  public vtkContourWidget(long id) { super(id); }
  public native long   VTKInit();

}
